==> qcad-3.5.1.0_2.txz: usr/local/share/qcad/scripts/Edit/DrawingPreferences/GridSettings/ts/GridSettings_pt.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pt_PT">
<context>
    <name>Grid</name>
    <message>
        <source>Display Grid</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Exibição de grade</translation>
    </message>
    <message>
        <source>Isometric Grid</source>
        <translation type="obsolete">Grade isométrica</translation>
    </message>
    <message>
        <source>Grid Spacing</source>
        <translatorcomment>--google--
Espaçamento Mínimo da Grade (px):
Espaçamento Mínimo da Grade (px)</translatorcomment>
        <translation type="obsolete">Espaçamento da grade</translation>
    </message>
    <message>
        <source>X:</source>
        <translatorcomment>--exact match--
--file: pt.po--
Fator &amp;x:
Fator x:
X:</translatorcomment>
        <translation type="obsolete">X:</translation>
    </message>
    <message>
        <source>View 3</source>
        <translation type="obsolete">Exiba 3</translation>
    </message>
    <message>
        <source>View 2</source>
        <translation type="obsolete">Exiba 2</translation>
    </message>
    <message>
        <source>View 4</source>
        <translation type="obsolete">Exiba 4</translation>
    </message>
    <message>
        <source>Y:</source>
        <translatorcomment>--exact match--
--file: pt.po--
Fator &amp;y:
Fator y:
Matriz:</translatorcomment>
        <translation type="obsolete">Y:</translation>
    </message>
    <message>
        <source>View 1</source>
        <translation type="obsolete">Exiba 1</translation>
    </message>
    <message>
        <source>Meta Grid Spacing</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Espaçamento da meta grade</translation>
    </message>
</context>
<context>
    <name>GridSettings</name>
    <message>
        <location filename="../GridSettings.js" line="+27"/>
        <source>General</source>
        <translatorcomment>--exact match--
--file: pt_PT.po--
Preferências Gerais do Aplicativo
[2000-206F] Pontuação Geral</translatorcomment>
        <translation>Geral</translation>
    </message>
    <message>
        <source>Default Grid</source>
        <translatorcomment>--google--
Configurações da página</translatorcomment>
        <translation type="obsolete">Grade padrão</translation>
    </message>
    <message>
        <location line="-2"/>
        <location line="+2"/>
        <source>Grid</source>
        <translatorcomment>--exact match--
--file: pt.po--
&amp;Grade
Grelha
Posicionamento na grade</translatorcomment>
        <translation>Grade</translation>
    </message>
    <message>
        <location line="-2"/>
        <source>Defaults for New Drawings</source>
        <translation>Padrões para novos desenhos</translation>
    </message>
    <message>
        <location line="+83"/>
        <location line="+103"/>
        <location line="+1"/>
        <location line="+22"/>
        <location line="+1"/>
        <source>auto</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pt.ts--
&amp;Automático
Automático
Salta automaticamente</translatorcomment>
        <translation>auto</translation>
    </message>
</context>
<context>
    <name>scrollArea</name>
    <message>
        <source>View 1</source>
        <translation type="vanished">Exiba 1</translation>
    </message>
    <message>
        <location filename="../PreferencesPage.ui" line="+29"/>
        <source>Viewport 1</source>
        <translation>Exiba 1</translation>
    </message>
    <message>
        <location line="+6"/>
        <location line="+152"/>
        <location line="+152"/>
        <location line="+152"/>
        <source>Display Grid</source>
        <translation>Exibição de grade</translation>
    </message>
    <message>
        <location line="-446"/>
        <location line="+152"/>
        <location line="+152"/>
        <location line="+152"/>
        <source>Isometric Grid</source>
        <translation>Grade isométrica</translation>
    </message>
    <message>
        <location line="-449"/>
        <location line="+152"/>
        <location line="+152"/>
        <location line="+152"/>
        <source>Grid Spacing</source>
        <translation>Espaçamento da grade</translation>
    </message>
    <message>
        <location line="-450"/>
        <location line="+90"/>
        <location line="+76"/>
        <location line="+89"/>
        <location line="+76"/>
        <location line="+56"/>
        <location line="+116"/>
        <location line="+30"/>
        <source>Y:</source>
        <translation>Y:</translation>
    </message>
    <message>
        <location line="-512"/>
        <location line="+76"/>
        <location line="+55"/>
        <location line="+63"/>
        <location line="+89"/>
        <location line="+90"/>
        <location line="+62"/>
        <location line="+63"/>
        <source>X:</source>
        <translation>X:</translation>
    </message>
    <message>
        <location line="-462"/>
        <location line="+152"/>
        <location line="+152"/>
        <location line="+152"/>
        <source>Meta Grid Spacing</source>
        <translation>Espaçamento da meta grade</translation>
    </message>
    <message>
        <location line="-390"/>
        <source>Viewport 2</source>
        <translation>Exiba 2</translation>
    </message>
    <message>
        <location line="+152"/>
        <source>Viewport 3</source>
        <translation>Exiba 3</translation>
    </message>
    <message>
        <location line="+152"/>
        <source>Viewport 4</source>
        <translation>Exiba 4</translation>
    </message>
    <message>
        <source>View 2</source>
        <translation type="vanished">Exiba 2</translation>
    </message>
    <message>
        <source>View 3</source>
        <translation type="vanished">Exiba 3</translation>
    </message>
    <message>
        <source>View 4</source>
        <translation type="vanished">Exiba 4</translation>
    </message>
</context>
</TS>

==> qcad-3.15.2.0.txz: usr/local/share/qcad/scripts/Edit/DrawingPreferences/GridSettings/ts/GridSettings_pt.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pt">
<context>
    <name>Grid</name>
    <message>
        <source>Display Grid</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Exibição de grade</translation>
    </message>
    <message>
        <source>Isometric Grid</source>
        <translation type="obsolete">Grade isométrica</translation>
    </message>
    <message>
        <source>Grid Spacing</source>
        <translatorcomment>--google--
Espaçamento Mínimo da Grade (px):
Espaçamento Mínimo da Grade (px)</translatorcomment>
        <translation type="obsolete">Espaçamento da grade</translation>
    </message>
    <message>
        <source>X:</source>
        <translatorcomment>--exact match--
--file: pt.po--
Fator &amp;x:
Fator x:
X:</translatorcomment>
        <translation type="obsolete">X:</translation>
    </message>
    <message>
        <source>View 3</source>
        <translation type="obsolete">Exiba 3</translation>
    </message>
    <message>
        <source>View 2</source>
        <translation type="obsolete">Exiba 2</translation>
    </message>
    <message>
        <source>View 4</source>
        <translation type="obsolete">Exiba 4</translation>
    </message>
    <message>
        <source>Y:</source>
        <translatorcomment>--exact match--
--file: pt.po--
Fator &amp;y:
Fator y:
Matriz:</translatorcomment>
        <translation type="obsolete">Y:</translation>
    </message>
    <message>
        <source>View 1</source>
        <translation type="obsolete">Exiba 1</translation>
    </message>
    <message>
        <source>Meta Grid Spacing</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Espaçamento da meta grade</translation>
    </message>
</context>
<context>
    <name>GridSettings</name>
    <message>
        <location filename="../GridSettings.js" line="+27"/>
        <source>General</source>
        <translatorcomment>--exact match--
--file: pt_PT.po--
Preferências Gerais do Aplicativo
[2000-206F] Pontuação Geral</translatorcomment>
        <translation>Geral</translation>
    </message>
    <message>
        <source>Default Grid</source>
        <translatorcomment>--google--
Configurações da página</translatorcomment>
        <translation type="obsolete">Grade padrão</translation>
    </message>
    <message>
        <location line="-2"/>
        <location line="+2"/>
        <source>Grid</source>
        <translatorcomment>--exact match--
--file: pt.po--
&amp;Grade
Grelha
Posicionamento na grade</translatorcomment>
        <translation>Grade</translation>
    </message>
    <message>
        <location line="-2"/>
        <source>Defaults for New Drawings</source>
        <translation>Padrões para Novos Desenhos</translation>
    </message>
    <message>
        <location line="+86"/>
        <location line="+103"/>
        <location line="+1"/>
        <location line="+22"/>
        <location line="+1"/>
        <source>auto</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pt.ts--
&amp;Automático
Automático
Salta automaticamente</translatorcomment>
        <translation>automático</translation>
    </message>
</context>
<context>
    <name>scrollArea</name>
    <message>
        <source>View 1</source>
        <translation type="vanished">Vista 1</translation>
    </message>
    <message>
        <location filename="../PreferencesPage.ui" line="+29"/>
        <source>Viewport 1</source>
        <translation>Âncora de Vista 1</translation>
    </message>
    <message>
        <location line="+6"/>
        <location line="+152"/>
        <location line="+152"/>
        <location line="+152"/>
        <source>Display Grid</source>
        <translation>Grade de Visualização</translation>
    </message>
    <message>
        <location line="-446"/>
        <location line="+152"/>
        <location line="+152"/>
        <location line="+152"/>
        <source>Isometric Grid</source>
        <translation>Grade Isométrica</translation>
    </message>
    <message>
        <location line="-449"/>
        <location line="+152"/>
        <location line="+152"/>
        <location line="+152"/>
        <source>Grid Spacing</source>
        <translation>Espaçamento da Grade</translation>
    </message>
    <message>
        <location line="-450"/>
        <location line="+90"/>
        <location line="+76"/>
        <location line="+89"/>
        <location line="+76"/>
        <location line="+56"/>
        <location line="+116"/>
        <location line="+30"/>
        <source>Y:</source>
        <translation>Y:</translation>
    </message>
    <message>
        <location line="-512"/>
        <location line="+76"/>
        <location line="+55"/>
        <location line="+63"/>
        <location line="+89"/>
        <location line="+90"/>
        <location line="+62"/>
        <location line="+63"/>
        <source>X:</source>
        <translation>X:</translation>
    </message>
    <message>
        <location line="-462"/>
        <location line="+152"/>
        <location line="+152"/>
        <location line="+152"/>
        <source>Meta Grid Spacing</source>
        <translation>Espaçamento da Metagrade</translation>
    </message>
    <message>
        <location line="-390"/>
        <source>Viewport 2</source>
        <translation>Âncora de Vista 2</translation>
    </message>
    <message>
        <location line="+152"/>
        <source>Viewport 3</source>
        <translation>Âncora de Vista 3</translation>
    </message>
    <message>
        <location line="+152"/>
        <source>Viewport 4</source>
        <translation>Âncora de Vista 4</translation>
    </message>
    <message>
        <source>View 2</source>
        <translation type="vanished">Vista 2</translation>
    </message>
    <message>
        <source>View 3</source>
        <translation type="vanished">Vista 3</translation>
    </message>
    <message>
        <source>View 4</source>
        <translation type="vanished">Vista 4</translation>
    </message>
</context>
</TS>
